@@ -292,7 +292,7 @@ class Cursor(DBAPICursor):
         buffer = client.getResultMetadata(self._query_id)
         buffer = BytesIO(buffer)
         self._rowcount, self._query_columns_description = get_query_columns_info(buffer)
-        _logger.info("finished populating metadata")
+        _logger.info("finished populating metadata", self._query_id)
         return self._query_id
 
     def rowcount(self):
